@@ -101,7 +101,6 @@ namespace kt
 			data_dir += bt::DirSeparator();
 
 		connect(&update_timer,SIGNAL(timeout()),this,SLOT(update()));
-		update_timer.start(CORE_UPDATE_INTERVAL);
 		
 		Uint16 port = Settings::port();
 		if (port == 0)
@@ -233,6 +232,17 @@ namespace kt
 			}
 		}
 		
+		if (qman->alreadyLoaded(tc->getInfoHash()))
+		{
+			Out(SYS_GEN|LOG_IMPORTANT) << "Torrent " << tc->getDisplayName() << " already loaded" << endl;
+			// Cleanup tor dir
+			QString dir = tc->getTorDir();
+			if (bt::Exists(dir))
+				bt::Delete(dir,true);
+			delete tc;
+			return false;
+		}
+		
 		connectSignals(tc);
 		qman->append(tc);
 	
@@ -578,7 +588,10 @@ namespace kt
 	
 	void Core::start(QList<bt::TorrentInterface*> & todo)
 	{
-		if (todo.count() == 0)
+		if (todo.isEmpty())
+			return;
+		
+		if (todo.count() == 1)
 		{
 			start(todo.front());
 		}
@@ -747,14 +760,11 @@ namespace kt
 	{
 		try
 		{
-			update_timer.stop();
 			// do nothing if new and old dir are the same
 			if (KUrl(data_dir) == KUrl(new_dir) || data_dir == (new_dir + bt::DirSeparator()))
-			{
-				update_timer.start(CORE_UPDATE_INTERVAL);
 				return true;
-			}
 
+			update_timer.stop();
 			// safety check
 			if (!bt::Exists(new_dir))
 				bt::MakeDir(new_dir);
@@ -852,38 +862,45 @@ namespace kt
 
 	void Core::update()
 	{
-		bt::UpdateCurrentTime();
-		AuthenticationMonitor::instance().update();
-		
-		QList<bt::TorrentInterface *>::iterator i = qman->begin();
-		bool updated = false;
-		while (i != qman->end())
+		try
 		{
-			bt::TorrentInterface* tc = *i;
-			if (tc->updateNeeded())
+			bt::UpdateCurrentTime();
+			AuthenticationMonitor::instance().update();
+			
+			QList<bt::TorrentInterface *>::iterator i = qman->begin();
+			bool updated = false;
+			while (i != qman->end())
 			{
-				tc->update();
-				updated = true;
+				bt::TorrentInterface* tc = *i;
+				if (tc->updateNeeded())
+				{
+					tc->update();
+					updated = true;
+				}
+				i++;
 			}
-			i++;
-		}
-		
-		if (!updated)
-		{
-			Out(SYS_GEN|LOG_DEBUG) << "Stopped update timer" << endl;
-			update_timer.stop(); // stop timer when not necessary
-			if (sleep_suppression_cookie != -1)
+			
+			if (!updated)
 			{
-				Solid::PowerManagement::stopSuppressingSleep(sleep_suppression_cookie);
-				Out(SYS_GEN|LOG_DEBUG) << "Stopped suppressing sleep" << endl;
-				sleep_suppression_cookie = -1;
+				Out(SYS_GEN|LOG_DEBUG) << "Stopped update timer" << endl;
+				update_timer.stop(); // stop timer when not necessary
+				if (sleep_suppression_cookie != -1)
+				{
+					Solid::PowerManagement::stopSuppressingSleep(sleep_suppression_cookie);
+					Out(SYS_GEN|LOG_DEBUG) << "Stopped suppressing sleep" << endl;
+					sleep_suppression_cookie = -1;
+				}
+			}
+			else
+			{
+				// check if the priority of stalled torrents must be decreased
+				if (Settings::decreasePriorityOfStalledTorrents())
+					qman->checkStalledTorrents(bt::GetCurrentTime(),Settings::stallTimer());
 			}
 		}
-		else
+		catch (bt::Error & err)
 		{
-			// check if the priority of stalled torrents must be decreased
-			if (Settings::decreasePriorityOfStalledTorrents())
-				qman->checkStalledTorrents(bt::GetCurrentTime(),Settings::stallTimer());
+			Out(SYS_GEN|LOG_IMPORTANT) << "Caught bt::Error: " << err.toString() << endl;
 		}
 	}
 
